Identification of the requirement to run a WebDAV server should be
considered. If it is not required then it should be disabled. However,
if it is required to meet the application functionality, then it
should be protected by SSL/TLS as well as the implementation of a
strong authentication mechanism.